Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6087)

Unified Diff: chrome/browser/infobars/infobar_delegate.h

Issue 15067008: [InfoBar] Add InfoBarDelegate::GetIconID() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Missed one Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/infobars/infobar_delegate.h
diff --git a/chrome/browser/infobars/infobar_delegate.h b/chrome/browser/infobars/infobar_delegate.h
index 1fb7d632a9d9b1197125bcdeefbc3e1bd00099e3..2401c537616b62e136a7faef99b1373958e917ee 100644
--- a/chrome/browser/infobars/infobar_delegate.h
+++ b/chrome/browser/infobars/infobar_delegate.h
@@ -78,9 +78,9 @@ class InfoBarDelegate {
// Called when the user clicks on the close button to dismiss the infobar.
virtual void InfoBarDismissed();
- // Return the icon to be shown for this InfoBar. If the returned Image is
- // NULL, no icon is shown.
- virtual gfx::Image* GetIcon() const;
+ // Return the resource ID of the icon to be shown for this InfoBar. If the
+ // value is equal to |kNoIconID|, no icon is shown.
+ virtual int GetIconID() const;
// Returns the type of the infobar. The type determines the appearance (such
// as background color) of the infobar.
@@ -99,6 +99,13 @@ class InfoBarDelegate {
virtual ThreeDAPIInfoBarDelegate* AsThreeDAPIInfoBarDelegate();
virtual TranslateInfoBarDelegate* AsTranslateInfoBarDelegate();
+ // Value to use when the InfoBar has no icon to show.
+ static const int kNoIconID = 0;
sky 2013/05/15 20:47:06 nit: constants should be above destructor.
gone 2013/05/15 21:43:00 Done.
+
+ // Return the icon to be shown for this InfoBar. If the returned Image is
+ // empty, no icon is shown.
+ gfx::Image GetIcon() const;
+
content::WebContents* web_contents() {
return owner_ ? owner_->web_contents() : NULL;
}

Powered by Google App Engine
This is Rietveld 408576698